# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class DownloadSingleInitiationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'business_object_data': 'BusinessObjectData',
        'aws_access_key': 'str',
        'aws_secret_key': 'str',
        'aws_session_token': 'str',
        'aws_session_expiration_time': 'datetime',
        'pre_signed_url': 'str'
    }

    attribute_map = {
        'business_object_data': 'businessObjectData',
        'aws_access_key': 'awsAccessKey',
        'aws_secret_key': 'awsSecretKey',
        'aws_session_token': 'awsSessionToken',
        'aws_session_expiration_time': 'awsSessionExpirationTime',
        'pre_signed_url': 'preSignedUrl'
    }

    def __init__(self, business_object_data=None, aws_access_key=None, aws_secret_key=None, aws_session_token=None, aws_session_expiration_time=None, pre_signed_url=None):  # noqa: E501
        """DownloadSingleInitiationResponse - a model defined in OpenAPI"""  # noqa: E501

        self._business_object_data = None
        self._aws_access_key = None
        self._aws_secret_key = None
        self._aws_session_token = None
        self._aws_session_expiration_time = None
        self._pre_signed_url = None
        self.discriminator = None

        self.business_object_data = business_object_data
        self.aws_access_key = aws_access_key
        self.aws_secret_key = aws_secret_key
        self.aws_session_token = aws_session_token
        self.aws_session_expiration_time = aws_session_expiration_time
        self.pre_signed_url = pre_signed_url

    @property
    def business_object_data(self):
        """Gets the business_object_data of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The business_object_data of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: BusinessObjectData
        """
        return self._business_object_data

    @business_object_data.setter
    def business_object_data(self, business_object_data):
        """Sets the business_object_data of this DownloadSingleInitiationResponse.


        :param business_object_data: The business_object_data of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: BusinessObjectData
        """
        if business_object_data is None:
            raise ValueError("Invalid value for `business_object_data`, must not be `None`")  # noqa: E501

        self._business_object_data = business_object_data

    @property
    def aws_access_key(self):
        """Gets the aws_access_key of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_access_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_access_key

    @aws_access_key.setter
    def aws_access_key(self, aws_access_key):
        """Sets the aws_access_key of this DownloadSingleInitiationResponse.


        :param aws_access_key: The aws_access_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_access_key is None:
            raise ValueError("Invalid value for `aws_access_key`, must not be `None`")  # noqa: E501

        self._aws_access_key = aws_access_key

    @property
    def aws_secret_key(self):
        """Gets the aws_secret_key of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_secret_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_secret_key

    @aws_secret_key.setter
    def aws_secret_key(self, aws_secret_key):
        """Sets the aws_secret_key of this DownloadSingleInitiationResponse.


        :param aws_secret_key: The aws_secret_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_secret_key is None:
            raise ValueError("Invalid value for `aws_secret_key`, must not be `None`")  # noqa: E501

        self._aws_secret_key = aws_secret_key

    @property
    def aws_session_token(self):
        """Gets the aws_session_token of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_session_token of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_session_token

    @aws_session_token.setter
    def aws_session_token(self, aws_session_token):
        """Sets the aws_session_token of this DownloadSingleInitiationResponse.


        :param aws_session_token: The aws_session_token of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_session_token is None:
            raise ValueError("Invalid value for `aws_session_token`, must not be `None`")  # noqa: E501

        self._aws_session_token = aws_session_token

    @property
    def aws_session_expiration_time(self):
        """Gets the aws_session_expiration_time of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_session_expiration_time of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._aws_session_expiration_time

    @aws_session_expiration_time.setter
    def aws_session_expiration_time(self, aws_session_expiration_time):
        """Sets the aws_session_expiration_time of this DownloadSingleInitiationResponse.


        :param aws_session_expiration_time: The aws_session_expiration_time of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: datetime
        """
        if aws_session_expiration_time is None:
            raise ValueError("Invalid value for `aws_session_expiration_time`, must not be `None`")  # noqa: E501

        self._aws_session_expiration_time = aws_session_expiration_time

    @property
    def pre_signed_url(self):
        """Gets the pre_signed_url of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The pre_signed_url of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._pre_signed_url

    @pre_signed_url.setter
    def pre_signed_url(self, pre_signed_url):
        """Sets the pre_signed_url of this DownloadSingleInitiationResponse.


        :param pre_signed_url: The pre_signed_url of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if pre_signed_url is None:
            raise ValueError("Invalid value for `pre_signed_url`, must not be `None`")  # noqa: E501

        self._pre_signed_url = pre_signed_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DownloadSingleInitiationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
