# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDefinitionDescriptionSuggestion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'business_object_definition_description_suggestion_key': 'BusinessObjectDefinitionDescriptionSuggestionKey',
        'description_suggestion': 'str',
        'status': 'str',
        'created_by_user_id': 'str',
        'created_on': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'business_object_definition_description_suggestion_key': 'businessObjectDefinitionDescriptionSuggestionKey',
        'description_suggestion': 'descriptionSuggestion',
        'status': 'status',
        'created_by_user_id': 'createdByUserId',
        'created_on': 'createdOn'
    }

    def __init__(self, id=None, business_object_definition_description_suggestion_key=None, description_suggestion=None, status=None, created_by_user_id=None, created_on=None):  # noqa: E501
        """BusinessObjectDefinitionDescriptionSuggestion - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._business_object_definition_description_suggestion_key = None
        self._description_suggestion = None
        self._status = None
        self._created_by_user_id = None
        self._created_on = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.business_object_definition_description_suggestion_key = business_object_definition_description_suggestion_key
        if description_suggestion is not None:
            self.description_suggestion = description_suggestion
        if status is not None:
            self.status = status
        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        if created_on is not None:
            self.created_on = created_on

    @property
    def id(self):
        """Gets the id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        A system unique ID of this business object definition description suggestion  # noqa: E501

        :return: The id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BusinessObjectDefinitionDescriptionSuggestion.

        A system unique ID of this business object definition description suggestion  # noqa: E501

        :param id: The id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def business_object_definition_description_suggestion_key(self):
        """Gets the business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501


        :return: The business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: BusinessObjectDefinitionDescriptionSuggestionKey
        """
        return self._business_object_definition_description_suggestion_key

    @business_object_definition_description_suggestion_key.setter
    def business_object_definition_description_suggestion_key(self, business_object_definition_description_suggestion_key):
        """Sets the business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.


        :param business_object_definition_description_suggestion_key: The business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: BusinessObjectDefinitionDescriptionSuggestionKey
        """
        if business_object_definition_description_suggestion_key is None:
            raise ValueError("Invalid value for `business_object_definition_description_suggestion_key`, must not be `None`")  # noqa: E501

        self._business_object_definition_description_suggestion_key = business_object_definition_description_suggestion_key

    @property
    def description_suggestion(self):
        """Gets the description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The description suggestion  # noqa: E501

        :return: The description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: str
        """
        return self._description_suggestion

    @description_suggestion.setter
    def description_suggestion(self, description_suggestion):
        """Sets the description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.

        The description suggestion  # noqa: E501

        :param description_suggestion: The description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: str
        """

        self._description_suggestion = description_suggestion

    @property
    def status(self):
        """Gets the status of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The status of the business object definition description suggestion. One of the following values: PENDING, ACCEPTED                  # noqa: E501

        :return: The status of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BusinessObjectDefinitionDescriptionSuggestion.

        The status of the business object definition description suggestion. One of the following values: PENDING, ACCEPTED                  # noqa: E501

        :param status: The status of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The User ID of the user who created this business object definition description suggestion  # noqa: E501

        :return: The created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.

        The User ID of the user who created this business object definition description suggestion  # noqa: E501

        :param created_by_user_id: The created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: str
        """

        self._created_by_user_id = created_by_user_id

    @property
    def created_on(self):
        """Gets the created_on of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The timestamp when this business object definition description suggestion was created on  # noqa: E501

        :return: The created_on of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this BusinessObjectDefinitionDescriptionSuggestion.

        The timestamp when this business object definition description suggestion was created on  # noqa: E501

        :param created_on: The created_on of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: datetime
        """

        self._created_on = created_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDefinitionDescriptionSuggestion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
