# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_data_notification_registration_api import BusinessObjectDataNotificationRegistrationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataNotificationRegistrationApi(unittest.TestCase):
    """BusinessObjectDataNotificationRegistrationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_data_notification_registration_api.BusinessObjectDataNotificationRegistrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_data_notification_registration_create_business_object_data_notification_registration(self):
        """Test case for business_object_data_notification_registration_create_business_object_data_notification_registration

        createBusinessObjectDataNotificationRegistration  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_delete_business_object_data_notification(self):
        """Test case for business_object_data_notification_registration_delete_business_object_data_notification

        deleteBusinessObjectDataNotification  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_get_business_object_data_notification_registration(self):
        """Test case for business_object_data_notification_registration_get_business_object_data_notification_registration

        getBusinessObjectDataNotificationRegistration  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_get_business_object_data_notification_registrations_by_namespace(self):
        """Test case for business_object_data_notification_registration_get_business_object_data_notification_registrations_by_namespace

        getBusinessObjectDataNotificationRegistrationsByNamespace  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_get_business_object_data_notification_registrations_by_notification_filter(self):
        """Test case for business_object_data_notification_registration_get_business_object_data_notification_registrations_by_notification_filter

        getBusinessObjectDataNotificationRegistrationsByNotificationFilter  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_update_business_object_data_notification_registration(self):
        """Test case for business_object_data_notification_registration_update_business_object_data_notification_registration

        updateBusinessObjectDataNotificationRegistration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
