# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_format_api import BusinessObjectFormatApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectFormatApi(unittest.TestCase):
    """BusinessObjectFormatApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_format_api.BusinessObjectFormatApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_format_create_business_object_format(self):
        """Test case for business_object_format_create_business_object_format

        createBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_delete_business_object_format(self):
        """Test case for business_object_format_delete_business_object_format

        deleteBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_generate_business_object_format_ddl(self):
        """Test case for business_object_format_generate_business_object_format_ddl

        generateBusinessObjectFormatDdl  # noqa: E501
        """
        pass

    def test_business_object_format_generate_business_object_format_ddl_collection(self):
        """Test case for business_object_format_generate_business_object_format_ddl_collection

        generateBusinessObjectFormatDdlCollection  # noqa: E501
        """
        pass

    def test_business_object_format_get_business_object_format(self):
        """Test case for business_object_format_get_business_object_format

        getBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_get_business_object_formats(self):
        """Test case for business_object_format_get_business_object_formats

        getBusinessObjectFormats  # noqa: E501
        """
        pass

    def test_business_object_format_get_business_object_formats_with_filters(self):
        """Test case for business_object_format_get_business_object_formats_with_filters

        getBusinessObjectFormatsWithFilters  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format(self):
        """Test case for business_object_format_update_business_object_format

        updateBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_attribute_definitions(self):
        """Test case for business_object_format_update_business_object_format_attribute_definitions

        updateBusinessObjectFormatAttributeDefinitions  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_attributes(self):
        """Test case for business_object_format_update_business_object_format_attributes

        updateBusinessObjectFormatAttributes  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_legal_hold(self):
        """Test case for business_object_format_update_business_object_format_legal_hold

        updateBusinessObjectFormatLegalHold  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_parents(self):
        """Test case for business_object_format_update_business_object_format_parents

        updateBusinessObjectFormatParents  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_record_flag(self):
        """Test case for business_object_format_update_business_object_format_record_flag

        updateBusinessObjectFormatRecordFlag  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_retention_information(self):
        """Test case for business_object_format_update_business_object_format_retention_information

        updateBusinessObjectFormatRetentionInformation  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_schema_backwards_compatible_changes(self):
        """Test case for business_object_format_update_business_object_format_schema_backwards_compatible_changes

        updateBusinessObjectFormatSchemaBackwardsCompatibleChanges  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
