# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_data_attribute_api import BusinessObjectDataAttributeApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataAttributeApi(unittest.TestCase):
    """BusinessObjectDataAttributeApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_data_attribute_api.BusinessObjectDataAttributeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_data_attribute_create_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_create_business_object_data_attribute

        createBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute1(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute1

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute2(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute2

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute3(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute3

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute4(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute4

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute1(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute1

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute2(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute2

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute3(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute3

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute4(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute4

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes1(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes1

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes2(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes2

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes3(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes3

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes4(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes4

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute1(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute1

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute2(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute2

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute3(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute3

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute4(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute4

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
