# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class TagCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tag_key': 'TagKey',
        'display_name': 'str',
        'search_score_multiplier': 'float',
        'description': 'str',
        'parent_tag_key': 'TagKey'
    }

    attribute_map = {
        'tag_key': 'tagKey',
        'display_name': 'displayName',
        'search_score_multiplier': 'searchScoreMultiplier',
        'description': 'description',
        'parent_tag_key': 'parentTagKey'
    }

    def __init__(self, tag_key=None, display_name=None, search_score_multiplier=None, description=None, parent_tag_key=None):  # noqa: E501
        """TagCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._tag_key = None
        self._display_name = None
        self._search_score_multiplier = None
        self._description = None
        self._parent_tag_key = None
        self.discriminator = None

        self.tag_key = tag_key
        self.display_name = display_name
        if search_score_multiplier is not None:
            self.search_score_multiplier = search_score_multiplier
        if description is not None:
            self.description = description
        if parent_tag_key is not None:
            self.parent_tag_key = parent_tag_key

    @property
    def tag_key(self):
        """Gets the tag_key of this TagCreateRequest.  # noqa: E501


        :return: The tag_key of this TagCreateRequest.  # noqa: E501
        :rtype: TagKey
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this TagCreateRequest.


        :param tag_key: The tag_key of this TagCreateRequest.  # noqa: E501
        :type: TagKey
        """
        if tag_key is None:
            raise ValueError("Invalid value for `tag_key`, must not be `None`")  # noqa: E501

        self._tag_key = tag_key

    @property
    def display_name(self):
        """Gets the display_name of this TagCreateRequest.  # noqa: E501

        The tag's name in plain text for human readability  # noqa: E501

        :return: The display_name of this TagCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this TagCreateRequest.

        The tag's name in plain text for human readability  # noqa: E501

        :param display_name: The display_name of this TagCreateRequest.  # noqa: E501
        :type: str
        """
        if display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def search_score_multiplier(self):
        """Gets the search_score_multiplier of this TagCreateRequest.  # noqa: E501

        An optional tag's search score multiplier. Search score multiplier is numeric and can be a decimal  # noqa: E501

        :return: The search_score_multiplier of this TagCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._search_score_multiplier

    @search_score_multiplier.setter
    def search_score_multiplier(self, search_score_multiplier):
        """Sets the search_score_multiplier of this TagCreateRequest.

        An optional tag's search score multiplier. Search score multiplier is numeric and can be a decimal  # noqa: E501

        :param search_score_multiplier: The search_score_multiplier of this TagCreateRequest.  # noqa: E501
        :type: float
        """

        self._search_score_multiplier = search_score_multiplier

    @property
    def description(self):
        """Gets the description of this TagCreateRequest.  # noqa: E501

        An optional description  # noqa: E501

        :return: The description of this TagCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TagCreateRequest.

        An optional description  # noqa: E501

        :param description: The description of this TagCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def parent_tag_key(self):
        """Gets the parent_tag_key of this TagCreateRequest.  # noqa: E501


        :return: The parent_tag_key of this TagCreateRequest.  # noqa: E501
        :rtype: TagKey
        """
        return self._parent_tag_key

    @parent_tag_key.setter
    def parent_tag_key(self, parent_tag_key):
        """Sets the parent_tag_key of this TagCreateRequest.


        :param parent_tag_key: The parent_tag_key of this TagCreateRequest.  # noqa: E501
        :type: TagKey
        """

        self._parent_tag_key = parent_tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
