# coding: utf-8

# flake8: noqa
"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from herdsdk.models.allowed_attribute_values_create_request import AllowedAttributeValuesCreateRequest
from herdsdk.models.allowed_attribute_values_delete_request import AllowedAttributeValuesDeleteRequest
from herdsdk.models.allowed_attribute_values_information import AllowedAttributeValuesInformation
from herdsdk.models.attribute import Attribute
from herdsdk.models.attribute_definition import AttributeDefinition
from herdsdk.models.attribute_value_filter import AttributeValueFilter
from herdsdk.models.attribute_value_list import AttributeValueList
from herdsdk.models.attribute_value_list_create_request import AttributeValueListCreateRequest
from herdsdk.models.attribute_value_list_key import AttributeValueListKey
from herdsdk.models.attribute_value_list_keys import AttributeValueListKeys
from herdsdk.models.aws_credential import AwsCredential
from herdsdk.models.build_information import BuildInformation
from herdsdk.models.business_object_data import BusinessObjectData
from herdsdk.models.business_object_data_attribute import BusinessObjectDataAttribute
from herdsdk.models.business_object_data_attribute_create_request import BusinessObjectDataAttributeCreateRequest
from herdsdk.models.business_object_data_attribute_key import BusinessObjectDataAttributeKey
from herdsdk.models.business_object_data_attribute_keys import BusinessObjectDataAttributeKeys
from herdsdk.models.business_object_data_attribute_update_request import BusinessObjectDataAttributeUpdateRequest
from herdsdk.models.business_object_data_attributes_update_request import BusinessObjectDataAttributesUpdateRequest
from herdsdk.models.business_object_data_availability import BusinessObjectDataAvailability
from herdsdk.models.business_object_data_availability_collection_request import BusinessObjectDataAvailabilityCollectionRequest
from herdsdk.models.business_object_data_availability_collection_response import BusinessObjectDataAvailabilityCollectionResponse
from herdsdk.models.business_object_data_availability_request import BusinessObjectDataAvailabilityRequest
from herdsdk.models.business_object_data_create_request import BusinessObjectDataCreateRequest
from herdsdk.models.business_object_data_ddl import BusinessObjectDataDdl
from herdsdk.models.business_object_data_ddl_collection_request import BusinessObjectDataDdlCollectionRequest
from herdsdk.models.business_object_data_ddl_collection_response import BusinessObjectDataDdlCollectionResponse
from herdsdk.models.business_object_data_ddl_output_format_enum import BusinessObjectDataDdlOutputFormatEnum
from herdsdk.models.business_object_data_ddl_request import BusinessObjectDataDdlRequest
from herdsdk.models.business_object_data_download_credential import BusinessObjectDataDownloadCredential
from herdsdk.models.business_object_data_invalidate_unregistered_request import BusinessObjectDataInvalidateUnregisteredRequest
from herdsdk.models.business_object_data_invalidate_unregistered_response import BusinessObjectDataInvalidateUnregisteredResponse
from herdsdk.models.business_object_data_key import BusinessObjectDataKey
from herdsdk.models.business_object_data_keys import BusinessObjectDataKeys
from herdsdk.models.business_object_data_legal_hold_update_request import BusinessObjectDataLegalHoldUpdateRequest
from herdsdk.models.business_object_data_notification_filter import BusinessObjectDataNotificationFilter
from herdsdk.models.business_object_data_notification_registration import BusinessObjectDataNotificationRegistration
from herdsdk.models.business_object_data_notification_registration_create_request import BusinessObjectDataNotificationRegistrationCreateRequest
from herdsdk.models.business_object_data_notification_registration_keys import BusinessObjectDataNotificationRegistrationKeys
from herdsdk.models.business_object_data_notification_registration_update_request import BusinessObjectDataNotificationRegistrationUpdateRequest
from herdsdk.models.business_object_data_parents_update_request import BusinessObjectDataParentsUpdateRequest
from herdsdk.models.business_object_data_partitions import BusinessObjectDataPartitions
from herdsdk.models.business_object_data_partitions_request import BusinessObjectDataPartitionsRequest
from herdsdk.models.business_object_data_retention_information_update_request import BusinessObjectDataRetentionInformationUpdateRequest
from herdsdk.models.business_object_data_retry_storage_policy_transition_request import BusinessObjectDataRetryStoragePolicyTransitionRequest
from herdsdk.models.business_object_data_search_filter import BusinessObjectDataSearchFilter
from herdsdk.models.business_object_data_search_key import BusinessObjectDataSearchKey
from herdsdk.models.business_object_data_search_request import BusinessObjectDataSearchRequest
from herdsdk.models.business_object_data_search_result import BusinessObjectDataSearchResult
from herdsdk.models.business_object_data_status import BusinessObjectDataStatus
from herdsdk.models.business_object_data_status_change_event import BusinessObjectDataStatusChangeEvent
from herdsdk.models.business_object_data_status_information import BusinessObjectDataStatusInformation
from herdsdk.models.business_object_data_status_update_request import BusinessObjectDataStatusUpdateRequest
from herdsdk.models.business_object_data_status_update_response import BusinessObjectDataStatusUpdateResponse
from herdsdk.models.business_object_data_storage_file_key import BusinessObjectDataStorageFileKey
from herdsdk.models.business_object_data_storage_files_create_request import BusinessObjectDataStorageFilesCreateRequest
from herdsdk.models.business_object_data_storage_files_create_response import BusinessObjectDataStorageFilesCreateResponse
from herdsdk.models.business_object_data_storage_unit_create_request import BusinessObjectDataStorageUnitCreateRequest
from herdsdk.models.business_object_data_storage_unit_create_response import BusinessObjectDataStorageUnitCreateResponse
from herdsdk.models.business_object_data_storage_unit_key import BusinessObjectDataStorageUnitKey
from herdsdk.models.business_object_data_storage_unit_status_update_request import BusinessObjectDataStorageUnitStatusUpdateRequest
from herdsdk.models.business_object_data_storage_unit_status_update_response import BusinessObjectDataStorageUnitStatusUpdateResponse
from herdsdk.models.business_object_data_upload_credential import BusinessObjectDataUploadCredential
from herdsdk.models.business_object_data_version import BusinessObjectDataVersion
from herdsdk.models.business_object_data_versions import BusinessObjectDataVersions
from herdsdk.models.business_object_definition import BusinessObjectDefinition
from herdsdk.models.business_object_definition_change_event import BusinessObjectDefinitionChangeEvent
from herdsdk.models.business_object_definition_column import BusinessObjectDefinitionColumn
from herdsdk.models.business_object_definition_column_change_event import BusinessObjectDefinitionColumnChangeEvent
from herdsdk.models.business_object_definition_column_create_request import BusinessObjectDefinitionColumnCreateRequest
from herdsdk.models.business_object_definition_column_key import BusinessObjectDefinitionColumnKey
from herdsdk.models.business_object_definition_column_keys import BusinessObjectDefinitionColumnKeys
from herdsdk.models.business_object_definition_column_search_filter import BusinessObjectDefinitionColumnSearchFilter
from herdsdk.models.business_object_definition_column_search_key import BusinessObjectDefinitionColumnSearchKey
from herdsdk.models.business_object_definition_column_search_request import BusinessObjectDefinitionColumnSearchRequest
from herdsdk.models.business_object_definition_column_search_response import BusinessObjectDefinitionColumnSearchResponse
from herdsdk.models.business_object_definition_column_update_request import BusinessObjectDefinitionColumnUpdateRequest
from herdsdk.models.business_object_definition_create_request import BusinessObjectDefinitionCreateRequest
from herdsdk.models.business_object_definition_description_suggestion import BusinessObjectDefinitionDescriptionSuggestion
from herdsdk.models.business_object_definition_description_suggestion_acceptance_request import BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest
from herdsdk.models.business_object_definition_description_suggestion_create_request import BusinessObjectDefinitionDescriptionSuggestionCreateRequest
from herdsdk.models.business_object_definition_description_suggestion_key import BusinessObjectDefinitionDescriptionSuggestionKey
from herdsdk.models.business_object_definition_description_suggestion_keys import BusinessObjectDefinitionDescriptionSuggestionKeys
from herdsdk.models.business_object_definition_description_suggestion_search_filter import BusinessObjectDefinitionDescriptionSuggestionSearchFilter
from herdsdk.models.business_object_definition_description_suggestion_search_key import BusinessObjectDefinitionDescriptionSuggestionSearchKey
from herdsdk.models.business_object_definition_description_suggestion_search_request import BusinessObjectDefinitionDescriptionSuggestionSearchRequest
from herdsdk.models.business_object_definition_description_suggestion_search_response import BusinessObjectDefinitionDescriptionSuggestionSearchResponse
from herdsdk.models.business_object_definition_description_suggestion_update_request import BusinessObjectDefinitionDescriptionSuggestionUpdateRequest
from herdsdk.models.business_object_definition_descriptive_information_update_request import BusinessObjectDefinitionDescriptiveInformationUpdateRequest
from herdsdk.models.business_object_definition_index_response import BusinessObjectDefinitionIndexResponse
from herdsdk.models.business_object_definition_key import BusinessObjectDefinitionKey
from herdsdk.models.business_object_definition_keys import BusinessObjectDefinitionKeys
from herdsdk.models.business_object_definition_sample_data_file_key import BusinessObjectDefinitionSampleDataFileKey
from herdsdk.models.business_object_definition_search_filter import BusinessObjectDefinitionSearchFilter
from herdsdk.models.business_object_definition_search_key import BusinessObjectDefinitionSearchKey
from herdsdk.models.business_object_definition_search_request import BusinessObjectDefinitionSearchRequest
from herdsdk.models.business_object_definition_search_response import BusinessObjectDefinitionSearchResponse
from herdsdk.models.business_object_definition_subject_matter_expert import BusinessObjectDefinitionSubjectMatterExpert
from herdsdk.models.business_object_definition_subject_matter_expert_create_request import BusinessObjectDefinitionSubjectMatterExpertCreateRequest
from herdsdk.models.business_object_definition_subject_matter_expert_key import BusinessObjectDefinitionSubjectMatterExpertKey
from herdsdk.models.business_object_definition_subject_matter_expert_keys import BusinessObjectDefinitionSubjectMatterExpertKeys
from herdsdk.models.business_object_definition_tag import BusinessObjectDefinitionTag
from herdsdk.models.business_object_definition_tag_create_request import BusinessObjectDefinitionTagCreateRequest
from herdsdk.models.business_object_definition_tag_key import BusinessObjectDefinitionTagKey
from herdsdk.models.business_object_definition_tag_keys import BusinessObjectDefinitionTagKeys
from herdsdk.models.business_object_definition_update_request import BusinessObjectDefinitionUpdateRequest
from herdsdk.models.business_object_format import BusinessObjectFormat
from herdsdk.models.business_object_format_attribute_definitions_update_request import BusinessObjectFormatAttributeDefinitionsUpdateRequest
from herdsdk.models.business_object_format_attributes_update_request import BusinessObjectFormatAttributesUpdateRequest
from herdsdk.models.business_object_format_create_request import BusinessObjectFormatCreateRequest
from herdsdk.models.business_object_format_ddl import BusinessObjectFormatDdl
from herdsdk.models.business_object_format_ddl_collection_request import BusinessObjectFormatDdlCollectionRequest
from herdsdk.models.business_object_format_ddl_collection_response import BusinessObjectFormatDdlCollectionResponse
from herdsdk.models.business_object_format_ddl_request import BusinessObjectFormatDdlRequest
from herdsdk.models.business_object_format_external_interface import BusinessObjectFormatExternalInterface
from herdsdk.models.business_object_format_external_interface_create_request import BusinessObjectFormatExternalInterfaceCreateRequest
from herdsdk.models.business_object_format_external_interface_descriptive_information import BusinessObjectFormatExternalInterfaceDescriptiveInformation
from herdsdk.models.business_object_format_external_interface_key import BusinessObjectFormatExternalInterfaceKey
from herdsdk.models.business_object_format_key import BusinessObjectFormatKey
from herdsdk.models.business_object_format_keys import BusinessObjectFormatKeys
from herdsdk.models.business_object_format_legal_hold_update_request import BusinessObjectFormatLegalHoldUpdateRequest
from herdsdk.models.business_object_format_parents_update_request import BusinessObjectFormatParentsUpdateRequest
from herdsdk.models.business_object_format_record_flag_update_request import BusinessObjectFormatRecordFlagUpdateRequest
from herdsdk.models.business_object_format_retention_information_update_request import BusinessObjectFormatRetentionInformationUpdateRequest
from herdsdk.models.business_object_format_schema_backwards_compatibility_update_request import BusinessObjectFormatSchemaBackwardsCompatibilityUpdateRequest
from herdsdk.models.business_object_format_update_request import BusinessObjectFormatUpdateRequest
from herdsdk.models.configuration_entry import ConfigurationEntry
from herdsdk.models.configuration_entry_keys import ConfigurationEntryKeys
from herdsdk.models.configuration_file import ConfigurationFile
from herdsdk.models.configuration_files import ConfigurationFiles
from herdsdk.models.custom_ddl import CustomDdl
from herdsdk.models.custom_ddl_create_request import CustomDdlCreateRequest
from herdsdk.models.custom_ddl_key import CustomDdlKey
from herdsdk.models.custom_ddl_keys import CustomDdlKeys
from herdsdk.models.custom_ddl_update_request import CustomDdlUpdateRequest
from herdsdk.models.data_provider import DataProvider
from herdsdk.models.data_provider_create_request import DataProviderCreateRequest
from herdsdk.models.data_provider_key import DataProviderKey
from herdsdk.models.data_provider_keys import DataProviderKeys
from herdsdk.models.descriptive_business_object_format import DescriptiveBusinessObjectFormat
from herdsdk.models.descriptive_business_object_format_update_request import DescriptiveBusinessObjectFormatUpdateRequest
from herdsdk.models.download_business_object_data_storage_file_single_initiation_request import DownloadBusinessObjectDataStorageFileSingleInitiationRequest
from herdsdk.models.download_business_object_data_storage_file_single_initiation_response import DownloadBusinessObjectDataStorageFileSingleInitiationResponse
from herdsdk.models.download_business_object_definition_sample_data_file_single_initiation_request import DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest
from herdsdk.models.download_business_object_definition_sample_data_file_single_initiation_response import DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationResponse
from herdsdk.models.download_single_initiation_response import DownloadSingleInitiationResponse
from herdsdk.models.email_send_request import EmailSendRequest
from herdsdk.models.emr_cluster import EmrCluster
from herdsdk.models.emr_cluster_create_request import EmrClusterCreateRequest
from herdsdk.models.emr_cluster_definition import EmrClusterDefinition
from herdsdk.models.emr_cluster_definition_application import EmrClusterDefinitionApplication
from herdsdk.models.emr_cluster_definition_auto_termination_policy import EmrClusterDefinitionAutoTerminationPolicy
from herdsdk.models.emr_cluster_definition_capacity_reservation_options import EmrClusterDefinitionCapacityReservationOptions
from herdsdk.models.emr_cluster_definition_configuration import EmrClusterDefinitionConfiguration
from herdsdk.models.emr_cluster_definition_create_request import EmrClusterDefinitionCreateRequest
from herdsdk.models.emr_cluster_definition_ebs_block_device_config import EmrClusterDefinitionEbsBlockDeviceConfig
from herdsdk.models.emr_cluster_definition_ebs_configuration import EmrClusterDefinitionEbsConfiguration
from herdsdk.models.emr_cluster_definition_information import EmrClusterDefinitionInformation
from herdsdk.models.emr_cluster_definition_instance_fleet import EmrClusterDefinitionInstanceFleet
from herdsdk.models.emr_cluster_definition_instance_type_config import EmrClusterDefinitionInstanceTypeConfig
from herdsdk.models.emr_cluster_definition_kerberos_attributes import EmrClusterDefinitionKerberosAttributes
from herdsdk.models.emr_cluster_definition_key import EmrClusterDefinitionKey
from herdsdk.models.emr_cluster_definition_keys import EmrClusterDefinitionKeys
from herdsdk.models.emr_cluster_definition_launch_specifications import EmrClusterDefinitionLaunchSpecifications
from herdsdk.models.emr_cluster_definition_on_demand_specification import EmrClusterDefinitionOnDemandSpecification
from herdsdk.models.emr_cluster_definition_spot_specification import EmrClusterDefinitionSpotSpecification
from herdsdk.models.emr_cluster_definition_update_request import EmrClusterDefinitionUpdateRequest
from herdsdk.models.emr_cluster_definition_volume_specification import EmrClusterDefinitionVolumeSpecification
from herdsdk.models.emr_cluster_ebs_block_device import EmrClusterEbsBlockDevice
from herdsdk.models.emr_cluster_instance_fleet import EmrClusterInstanceFleet
from herdsdk.models.emr_cluster_instance_fleet_provisioning_specifications import EmrClusterInstanceFleetProvisioningSpecifications
from herdsdk.models.emr_cluster_instance_fleet_state_change_reason import EmrClusterInstanceFleetStateChangeReason
from herdsdk.models.emr_cluster_instance_fleet_status import EmrClusterInstanceFleetStatus
from herdsdk.models.emr_cluster_instance_fleet_timeline import EmrClusterInstanceFleetTimeline
from herdsdk.models.emr_cluster_instance_type_configuration import EmrClusterInstanceTypeConfiguration
from herdsdk.models.emr_cluster_instance_type_specification import EmrClusterInstanceTypeSpecification
from herdsdk.models.emr_cluster_spot_provisioning_specification import EmrClusterSpotProvisioningSpecification
from herdsdk.models.emr_cluster_volume_specification import EmrClusterVolumeSpecification
from herdsdk.models.emr_hadoop_jar_step import EmrHadoopJarStep
from herdsdk.models.emr_hadoop_jar_step_add_request import EmrHadoopJarStepAddRequest
from herdsdk.models.emr_hive_step import EmrHiveStep
from herdsdk.models.emr_hive_step_add_request import EmrHiveStepAddRequest
from herdsdk.models.emr_master_security_group import EmrMasterSecurityGroup
from herdsdk.models.emr_master_security_group_add_request import EmrMasterSecurityGroupAddRequest
from herdsdk.models.emr_pig_step import EmrPigStep
from herdsdk.models.emr_pig_step_add_request import EmrPigStepAddRequest
from herdsdk.models.emr_shell_step import EmrShellStep
from herdsdk.models.emr_shell_step_add_request import EmrShellStepAddRequest
from herdsdk.models.emr_step import EmrStep
from herdsdk.models.error_information import ErrorInformation
from herdsdk.models.expected_partition_value_information import ExpectedPartitionValueInformation
from herdsdk.models.expected_partition_value_key import ExpectedPartitionValueKey
from herdsdk.models.expected_partition_values_create_request import ExpectedPartitionValuesCreateRequest
from herdsdk.models.expected_partition_values_delete_request import ExpectedPartitionValuesDeleteRequest
from herdsdk.models.expected_partition_values_information import ExpectedPartitionValuesInformation
from herdsdk.models.external_interface import ExternalInterface
from herdsdk.models.external_interface_create_request import ExternalInterfaceCreateRequest
from herdsdk.models.external_interface_key import ExternalInterfaceKey
from herdsdk.models.external_interface_keys import ExternalInterfaceKeys
from herdsdk.models.external_interface_update_request import ExternalInterfaceUpdateRequest
from herdsdk.models.facet import Facet
from herdsdk.models.field import Field
from herdsdk.models.file import File
from herdsdk.models.file_type import FileType
from herdsdk.models.file_type_create_request import FileTypeCreateRequest
from herdsdk.models.file_type_key import FileTypeKey
from herdsdk.models.file_type_keys import FileTypeKeys
from herdsdk.models.global_attribute_definition import GlobalAttributeDefinition
from herdsdk.models.global_attribute_definition_create_request import GlobalAttributeDefinitionCreateRequest
from herdsdk.models.global_attribute_definition_key import GlobalAttributeDefinitionKey
from herdsdk.models.global_attribute_definition_keys import GlobalAttributeDefinitionKeys
from herdsdk.models.hadoop_jar_step import HadoopJarStep
from herdsdk.models.highlight import Highlight
from herdsdk.models.index_search_filter import IndexSearchFilter
from herdsdk.models.index_search_key import IndexSearchKey
from herdsdk.models.index_search_request import IndexSearchRequest
from herdsdk.models.index_search_response import IndexSearchResponse
from herdsdk.models.index_search_result import IndexSearchResult
from herdsdk.models.index_search_result_key import IndexSearchResultKey
from herdsdk.models.index_search_result_type_key import IndexSearchResultTypeKey
from herdsdk.models.instance_definition import InstanceDefinition
from herdsdk.models.instance_definitions import InstanceDefinitions
from herdsdk.models.jdbc_connection import JdbcConnection
from herdsdk.models.jdbc_database_type import JdbcDatabaseType
from herdsdk.models.jdbc_execution_request import JdbcExecutionRequest
from herdsdk.models.jdbc_execution_response import JdbcExecutionResponse
from herdsdk.models.jdbc_statement import JdbcStatement
from herdsdk.models.jdbc_statement_result_set import JdbcStatementResultSet
from herdsdk.models.jdbc_statement_result_set_row import JdbcStatementResultSetRow
from herdsdk.models.jdbc_statement_status import JdbcStatementStatus
from herdsdk.models.jdbc_statement_type import JdbcStatementType
from herdsdk.models.job import Job
from herdsdk.models.job_action import JobAction
from herdsdk.models.job_action_enum import JobActionEnum
from herdsdk.models.job_create_request import JobCreateRequest
from herdsdk.models.job_definition import JobDefinition
from herdsdk.models.job_definition_create_request import JobDefinitionCreateRequest
from herdsdk.models.job_definition_key import JobDefinitionKey
from herdsdk.models.job_definition_keys import JobDefinitionKeys
from herdsdk.models.job_definition_update_request import JobDefinitionUpdateRequest
from herdsdk.models.job_delete_request import JobDeleteRequest
from herdsdk.models.job_signal_request import JobSignalRequest
from herdsdk.models.job_status_enum import JobStatusEnum
from herdsdk.models.job_summaries import JobSummaries
from herdsdk.models.job_summary import JobSummary
from herdsdk.models.job_update_request import JobUpdateRequest
from herdsdk.models.key_value_pair_configuration import KeyValuePairConfiguration
from herdsdk.models.key_value_pair_configurations import KeyValuePairConfigurations
from herdsdk.models.latest_after_partition_value import LatestAfterPartitionValue
from herdsdk.models.latest_before_partition_value import LatestBeforePartitionValue
from herdsdk.models.master_instance_definition import MasterInstanceDefinition
from herdsdk.models.message_header_definition import MessageHeaderDefinition
from herdsdk.models.namespace import Namespace
from herdsdk.models.namespace_authorization import NamespaceAuthorization
from herdsdk.models.namespace_create_request import NamespaceCreateRequest
from herdsdk.models.namespace_iam_role_authorization import NamespaceIamRoleAuthorization
from herdsdk.models.namespace_iam_role_authorization_create_request import NamespaceIamRoleAuthorizationCreateRequest
from herdsdk.models.namespace_iam_role_authorization_key import NamespaceIamRoleAuthorizationKey
from herdsdk.models.namespace_iam_role_authorization_keys import NamespaceIamRoleAuthorizationKeys
from herdsdk.models.namespace_iam_role_authorization_update_request import NamespaceIamRoleAuthorizationUpdateRequest
from herdsdk.models.namespace_key import NamespaceKey
from herdsdk.models.namespace_keys import NamespaceKeys
from herdsdk.models.namespace_permission_enum import NamespacePermissionEnum
from herdsdk.models.namespace_search_filter import NamespaceSearchFilter
from herdsdk.models.namespace_search_key import NamespaceSearchKey
from herdsdk.models.namespace_search_request import NamespaceSearchRequest
from herdsdk.models.namespace_search_response import NamespaceSearchResponse
from herdsdk.models.namespace_update_request import NamespaceUpdateRequest
from herdsdk.models.node_tag import NodeTag
from herdsdk.models.notification_message_definition import NotificationMessageDefinition
from herdsdk.models.notification_message_definitions import NotificationMessageDefinitions
from herdsdk.models.notification_registration_key import NotificationRegistrationKey
from herdsdk.models.notification_registration_status_update_request import NotificationRegistrationStatusUpdateRequest
from herdsdk.models.notification_registration_status_update_response import NotificationRegistrationStatusUpdateResponse
from herdsdk.models.parameter import Parameter
from herdsdk.models.partition import Partition
from herdsdk.models.partition_column import PartitionColumn
from herdsdk.models.partition_key_group import PartitionKeyGroup
from herdsdk.models.partition_key_group_create_request import PartitionKeyGroupCreateRequest
from herdsdk.models.partition_key_group_key import PartitionKeyGroupKey
from herdsdk.models.partition_key_group_keys import PartitionKeyGroupKeys
from herdsdk.models.partition_value_filter import PartitionValueFilter
from herdsdk.models.partition_value_range import PartitionValueRange
from herdsdk.models.registration_date_range_filter import RegistrationDateRangeFilter
from herdsdk.models.relational_table_registration_create_request import RelationalTableRegistrationCreateRequest
from herdsdk.models.relational_table_registration_delete_response import RelationalTableRegistrationDeleteResponse
from herdsdk.models.run_oozie_workflow_request import RunOozieWorkflowRequest
from herdsdk.models.s3_key_prefix_information import S3KeyPrefixInformation
from herdsdk.models.s3_properties_location import S3PropertiesLocation
from herdsdk.models.sample_data_file import SampleDataFile
from herdsdk.models.schema import Schema
from herdsdk.models.schema_column import SchemaColumn
from herdsdk.models.script_definition import ScriptDefinition
from herdsdk.models.search_index import SearchIndex
from herdsdk.models.search_index_activation import SearchIndexActivation
from herdsdk.models.search_index_activation_create_request import SearchIndexActivationCreateRequest
from herdsdk.models.search_index_create_request import SearchIndexCreateRequest
from herdsdk.models.search_index_key import SearchIndexKey
from herdsdk.models.search_index_keys import SearchIndexKeys
from herdsdk.models.search_index_statistics import SearchIndexStatistics
from herdsdk.models.security_function import SecurityFunction
from herdsdk.models.security_function_create_request import SecurityFunctionCreateRequest
from herdsdk.models.security_function_key import SecurityFunctionKey
from herdsdk.models.security_function_keys import SecurityFunctionKeys
from herdsdk.models.security_role import SecurityRole
from herdsdk.models.security_role_create_request import SecurityRoleCreateRequest
from herdsdk.models.security_role_function import SecurityRoleFunction
from herdsdk.models.security_role_function_create_request import SecurityRoleFunctionCreateRequest
from herdsdk.models.security_role_function_key import SecurityRoleFunctionKey
from herdsdk.models.security_role_function_keys import SecurityRoleFunctionKeys
from herdsdk.models.security_role_key import SecurityRoleKey
from herdsdk.models.security_role_keys import SecurityRoleKeys
from herdsdk.models.security_role_update_request import SecurityRoleUpdateRequest
from herdsdk.models.status_change_reason import StatusChangeReason
from herdsdk.models.status_timeline import StatusTimeline
from herdsdk.models.storage import Storage
from herdsdk.models.storage_attributes_update_request import StorageAttributesUpdateRequest
from herdsdk.models.storage_business_object_definition_daily_upload_stat import StorageBusinessObjectDefinitionDailyUploadStat
from herdsdk.models.storage_business_object_definition_daily_upload_stats import StorageBusinessObjectDefinitionDailyUploadStats
from herdsdk.models.storage_create_request import StorageCreateRequest
from herdsdk.models.storage_daily_upload_stat import StorageDailyUploadStat
from herdsdk.models.storage_daily_upload_stats import StorageDailyUploadStats
from herdsdk.models.storage_directory import StorageDirectory
from herdsdk.models.storage_file import StorageFile
from herdsdk.models.storage_key import StorageKey
from herdsdk.models.storage_keys import StorageKeys
from herdsdk.models.storage_platform import StoragePlatform
from herdsdk.models.storage_platforms import StoragePlatforms
from herdsdk.models.storage_policy import StoragePolicy
from herdsdk.models.storage_policy_create_request import StoragePolicyCreateRequest
from herdsdk.models.storage_policy_filter import StoragePolicyFilter
from herdsdk.models.storage_policy_key import StoragePolicyKey
from herdsdk.models.storage_policy_keys import StoragePolicyKeys
from herdsdk.models.storage_policy_rule import StoragePolicyRule
from herdsdk.models.storage_policy_transition import StoragePolicyTransition
from herdsdk.models.storage_policy_update_request import StoragePolicyUpdateRequest
from herdsdk.models.storage_unit import StorageUnit
from herdsdk.models.storage_unit_create_request import StorageUnitCreateRequest
from herdsdk.models.storage_unit_download_credential import StorageUnitDownloadCredential
from herdsdk.models.storage_unit_notification_filter import StorageUnitNotificationFilter
from herdsdk.models.storage_unit_notification_registration import StorageUnitNotificationRegistration
from herdsdk.models.storage_unit_notification_registration_create_request import StorageUnitNotificationRegistrationCreateRequest
from herdsdk.models.storage_unit_notification_registration_keys import StorageUnitNotificationRegistrationKeys
from herdsdk.models.storage_unit_notification_registration_update_request import StorageUnitNotificationRegistrationUpdateRequest
from herdsdk.models.storage_unit_status_change_event import StorageUnitStatusChangeEvent
from herdsdk.models.storage_unit_upload_credential import StorageUnitUploadCredential
from herdsdk.models.storage_update_request import StorageUpdateRequest
from herdsdk.models.subject_matter_expert import SubjectMatterExpert
from herdsdk.models.subject_matter_expert_contact_details import SubjectMatterExpertContactDetails
from herdsdk.models.subject_matter_expert_key import SubjectMatterExpertKey
from herdsdk.models.system_job_run_request import SystemJobRunRequest
from herdsdk.models.system_job_run_response import SystemJobRunResponse
from herdsdk.models.tag import Tag
from herdsdk.models.tag_child import TagChild
from herdsdk.models.tag_create_request import TagCreateRequest
from herdsdk.models.tag_key import TagKey
from herdsdk.models.tag_list_response import TagListResponse
from herdsdk.models.tag_search_filter import TagSearchFilter
from herdsdk.models.tag_search_key import TagSearchKey
from herdsdk.models.tag_search_request import TagSearchRequest
from herdsdk.models.tag_search_response import TagSearchResponse
from herdsdk.models.tag_type import TagType
from herdsdk.models.tag_type_create_request import TagTypeCreateRequest
from herdsdk.models.tag_type_key import TagTypeKey
from herdsdk.models.tag_type_keys import TagTypeKeys
from herdsdk.models.tag_type_search_request import TagTypeSearchRequest
from herdsdk.models.tag_type_search_response import TagTypeSearchResponse
from herdsdk.models.tag_type_update_request import TagTypeUpdateRequest
from herdsdk.models.tag_update_request import TagUpdateRequest
from herdsdk.models.timeout_validation_response import TimeoutValidationResponse
from herdsdk.models.upload_business_object_definition_sample_data_file_initiation_request import UploadBusinessObjectDefinitionSampleDataFileInitiationRequest
from herdsdk.models.upload_business_object_definition_sample_data_file_initiation_response import UploadBusinessObjectDefinitionSampleDataFileInitiationResponse
from herdsdk.models.upload_single_credential_extension_response import UploadSingleCredentialExtensionResponse
from herdsdk.models.upload_single_initiation_request import UploadSingleInitiationRequest
from herdsdk.models.upload_single_initiation_response import UploadSingleInitiationResponse
from herdsdk.models.user_authorizations import UserAuthorizations
from herdsdk.models.user_namespace_authorization import UserNamespaceAuthorization
from herdsdk.models.user_namespace_authorization_create_request import UserNamespaceAuthorizationCreateRequest
from herdsdk.models.user_namespace_authorization_key import UserNamespaceAuthorizationKey
from herdsdk.models.user_namespace_authorization_update_request import UserNamespaceAuthorizationUpdateRequest
from herdsdk.models.user_namespace_authorizations import UserNamespaceAuthorizations
from herdsdk.models.workflow_error import WorkflowError
from herdsdk.models.workflow_step import WorkflowStep
