# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.partition_key_group_api import PartitionKeyGroupApi  # noqa: E501
from herdsdk.rest import ApiException


class TestPartitionKeyGroupApi(unittest.TestCase):
    """PartitionKeyGroupApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.partition_key_group_api.PartitionKeyGroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_partition_key_group_create_partition_key_group(self):
        """Test case for partition_key_group_create_partition_key_group

        createPartitionKeyGroup  # noqa: E501
        """
        pass

    def test_partition_key_group_delete_partition_key_group(self):
        """Test case for partition_key_group_delete_partition_key_group

        deletePartitionKeyGroup  # noqa: E501
        """
        pass

    def test_partition_key_group_get_partition_key_group(self):
        """Test case for partition_key_group_get_partition_key_group

        getPartitionKeyGroup  # noqa: E501
        """
        pass

    def test_partition_key_group_get_partition_key_groups(self):
        """Test case for partition_key_group_get_partition_key_groups

        getPartitionKeyGroups  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
