# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.models.business_object_data_retry_storage_policy_transition_request import BusinessObjectDataRetryStoragePolicyTransitionRequest  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataRetryStoragePolicyTransitionRequest(unittest.TestCase):
    """BusinessObjectDataRetryStoragePolicyTransitionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBusinessObjectDataRetryStoragePolicyTransitionRequest(self):
        """Test BusinessObjectDataRetryStoragePolicyTransitionRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = herdsdk.models.business_object_data_retry_storage_policy_transition_request.BusinessObjectDataRetryStoragePolicyTransitionRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
