# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.upload_and_download_api import UploadAndDownloadApi  # noqa: E501
from herdsdk.rest import ApiException


class TestUploadAndDownloadApi(unittest.TestCase):
    """UploadAndDownloadApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.upload_and_download_api.UploadAndDownloadApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_uploadand_download_extend_upload_single_credentials(self):
        """Test case for uploadand_download_extend_upload_single_credentials

        extendUploadSingleCredentials  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_download_single(self):
        """Test case for uploadand_download_initiate_download_single

        initiateDownloadSingle  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_download_single_business_object_data_storage_file(self):
        """Test case for uploadand_download_initiate_download_single_business_object_data_storage_file

        initiateDownloadSingleBusinessObjectDataStorageFile  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_download_single_sample_file(self):
        """Test case for uploadand_download_initiate_download_single_sample_file

        initiateDownloadSingleSampleFile  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_upload_sample_file(self):
        """Test case for uploadand_download_initiate_upload_sample_file

        initiateUploadSampleFile  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_upload_single(self):
        """Test case for uploadand_download_initiate_upload_single

        initiateUploadSingle  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
