# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.tag_type_api import TagTypeApi  # noqa: E501
from herdsdk.rest import ApiException


class TestTagTypeApi(unittest.TestCase):
    """TagTypeApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.tag_type_api.TagTypeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_tag_type_create_tag_type(self):
        """Test case for tag_type_create_tag_type

        createTagType  # noqa: E501
        """
        pass

    def test_tag_type_delete_tag_type(self):
        """Test case for tag_type_delete_tag_type

        deleteTagType  # noqa: E501
        """
        pass

    def test_tag_type_get_tag_type(self):
        """Test case for tag_type_get_tag_type

        getTagType  # noqa: E501
        """
        pass

    def test_tag_type_get_tag_types(self):
        """Test case for tag_type_get_tag_types

        getTagTypes  # noqa: E501
        """
        pass

    def test_tag_type_search_tag_types(self):
        """Test case for tag_type_search_tag_types

        searchTagTypes  # noqa: E501
        """
        pass

    def test_tag_type_update_tag_type(self):
        """Test case for tag_type_update_tag_type

        updateTagType  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
