# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDefinitionCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'data_provider_name': 'str',
        'description': 'str',
        'display_name': 'str',
        'attributes': 'list[Attribute]'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'data_provider_name': 'dataProviderName',
        'description': 'description',
        'display_name': 'displayName',
        'attributes': 'attributes'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, data_provider_name=None, description=None, display_name=None, attributes=None):  # noqa: E501
        """BusinessObjectDefinitionCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._data_provider_name = None
        self._description = None
        self._display_name = None
        self._attributes = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.data_provider_name = data_provider_name
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if attributes is not None:
            self.attributes = attributes

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        The name of a valid Namespace known by the system  # noqa: E501

        :return: The namespace of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDefinitionCreateRequest.

        The name of a valid Namespace known by the system  # noqa: E501

        :param namespace: The namespace of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        The name for this Business Object Definition  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDefinitionCreateRequest.

        The name for this Business Object Definition  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def data_provider_name(self):
        """Gets the data_provider_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        The name of a valid Data Provider known by the system  # noqa: E501

        :return: The data_provider_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._data_provider_name

    @data_provider_name.setter
    def data_provider_name(self, data_provider_name):
        """Sets the data_provider_name of this BusinessObjectDefinitionCreateRequest.

        The name of a valid Data Provider known by the system  # noqa: E501

        :param data_provider_name: The data_provider_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """
        if data_provider_name is None:
            raise ValueError("Invalid value for `data_provider_name`, must not be `None`")  # noqa: E501

        self._data_provider_name = data_provider_name

    @property
    def description(self):
        """Gets the description of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        An optional description  # noqa: E501

        :return: The description of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectDefinitionCreateRequest.

        An optional description  # noqa: E501

        :param description: The description of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        An optional business friendly name  # noqa: E501

        :return: The display_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BusinessObjectDefinitionCreateRequest.

        An optional business friendly name  # noqa: E501

        :param display_name: The display_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def attributes(self):
        """Gets the attributes of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        Custom user-defined metadata associated with this Business Object Definition. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :return: The attributes of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this BusinessObjectDefinitionCreateRequest.

        Custom user-defined metadata associated with this Business Object Definition. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :param attributes: The attributes of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDefinitionCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
