# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.external_interface_api import ExternalInterfaceApi  # noqa: E501
from herdsdk.rest import ApiException


class TestExternalInterfaceApi(unittest.TestCase):
    """ExternalInterfaceApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.external_interface_api.ExternalInterfaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_external_interface_create_external_interface(self):
        """Test case for external_interface_create_external_interface

        createExternalInterface  # noqa: E501
        """
        pass

    def test_external_interface_delete_external_interface(self):
        """Test case for external_interface_delete_external_interface

        deleteExternalInterface  # noqa: E501
        """
        pass

    def test_external_interface_get_external_interface(self):
        """Test case for external_interface_get_external_interface

        getExternalInterface  # noqa: E501
        """
        pass

    def test_external_interface_get_external_interfaces(self):
        """Test case for external_interface_get_external_interfaces

        getExternalInterfaces  # noqa: E501
        """
        pass

    def test_external_interface_update_external_interface(self):
        """Test case for external_interface_update_external_interface

        updateExternalInterface  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
