# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.file_type_api import FileTypeApi  # noqa: E501
from herdsdk.rest import ApiException


class TestFileTypeApi(unittest.TestCase):
    """FileTypeApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.file_type_api.FileTypeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_file_type_create_file_type(self):
        """Test case for file_type_create_file_type

        createFileType  # noqa: E501
        """
        pass

    def test_file_type_delete_file_type(self):
        """Test case for file_type_delete_file_type

        deleteFileType  # noqa: E501
        """
        pass

    def test_file_type_get_file_type(self):
        """Test case for file_type_get_file_type

        getFileType  # noqa: E501
        """
        pass

    def test_file_type_get_file_types(self):
        """Test case for file_type_get_file_types

        getFileTypes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
