# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.storage_policy_api import StoragePolicyApi  # noqa: E501
from herdsdk.rest import ApiException


class TestStoragePolicyApi(unittest.TestCase):
    """StoragePolicyApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.storage_policy_api.StoragePolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_storage_policy_create_storage_policy(self):
        """Test case for storage_policy_create_storage_policy

        createStoragePolicy  # noqa: E501
        """
        pass

    def test_storage_policy_delete_storage_policy(self):
        """Test case for storage_policy_delete_storage_policy

        deleteStoragePolicy  # noqa: E501
        """
        pass

    def test_storage_policy_get_storage_policy(self):
        """Test case for storage_policy_get_storage_policy

        getStoragePolicy  # noqa: E501
        """
        pass

    def test_storage_policy_get_storage_policy_keys(self):
        """Test case for storage_policy_get_storage_policy_keys

        getStoragePolicyKeys  # noqa: E501
        """
        pass

    def test_storage_policy_update_storage_policy(self):
        """Test case for storage_policy_update_storage_policy

        updateStoragePolicy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
