# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.tag_api import TagApi  # noqa: E501
from herdsdk.rest import ApiException


class TestTagApi(unittest.TestCase):
    """TagApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.tag_api.TagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_tag_create_tag(self):
        """Test case for tag_create_tag

        createTag  # noqa: E501
        """
        pass

    def test_tag_delete_tag(self):
        """Test case for tag_delete_tag

        deleteTag  # noqa: E501
        """
        pass

    def test_tag_get_tag(self):
        """Test case for tag_get_tag

        getTag  # noqa: E501
        """
        pass

    def test_tag_get_tags(self):
        """Test case for tag_get_tags

        getTags  # noqa: E501
        """
        pass

    def test_tag_search_tags(self):
        """Test case for tag_search_tags

        searchTags  # noqa: E501
        """
        pass

    def test_tag_update_tag(self):
        """Test case for tag_update_tag

        updateTag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
