# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_data_api import BusinessObjectDataApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataApi(unittest.TestCase):
    """BusinessObjectDataApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_data_api.BusinessObjectDataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_data_check_business_object_data_availability(self):
        """Test case for business_object_data_check_business_object_data_availability

        checkBusinessObjectDataAvailability  # noqa: E501
        """
        pass

    def test_business_object_data_check_business_object_data_availability_collection(self):
        """Test case for business_object_data_check_business_object_data_availability_collection

        checkBusinessObjectDataAvailabilityCollection  # noqa: E501
        """
        pass

    def test_business_object_data_create_business_object_data(self):
        """Test case for business_object_data_create_business_object_data

        createBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data(self):
        """Test case for business_object_data_delete_business_object_data

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data1(self):
        """Test case for business_object_data_delete_business_object_data1

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data2(self):
        """Test case for business_object_data_delete_business_object_data2

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data3(self):
        """Test case for business_object_data_delete_business_object_data3

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data4(self):
        """Test case for business_object_data_delete_business_object_data4

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_destroy_business_object_data(self):
        """Test case for business_object_data_destroy_business_object_data

        destroyBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_generate_business_object_data_ddl(self):
        """Test case for business_object_data_generate_business_object_data_ddl

        generateBusinessObjectDataDdl  # noqa: E501
        """
        pass

    def test_business_object_data_generate_business_object_data_ddl_collection(self):
        """Test case for business_object_data_generate_business_object_data_ddl_collection

        generateBusinessObjectDataDdlCollection  # noqa: E501
        """
        pass

    def test_business_object_data_generate_business_object_data_partitions(self):
        """Test case for business_object_data_generate_business_object_data_partitions

        generateBusinessObjectDataPartitions  # noqa: E501
        """
        pass

    def test_business_object_data_get_all_business_object_data_by_business_object_definition(self):
        """Test case for business_object_data_get_all_business_object_data_by_business_object_definition

        getAllBusinessObjectDataByBusinessObjectDefinition  # noqa: E501
        """
        pass

    def test_business_object_data_get_all_business_object_data_by_business_object_format(self):
        """Test case for business_object_data_get_all_business_object_data_by_business_object_format

        getAllBusinessObjectDataByBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_data_get_business_object_data(self):
        """Test case for business_object_data_get_business_object_data

        getBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_get_business_object_data_versions(self):
        """Test case for business_object_data_get_business_object_data_versions

        getBusinessObjectDataVersions  # noqa: E501
        """
        pass

    def test_business_object_data_get_s3_key_prefix(self):
        """Test case for business_object_data_get_s3_key_prefix

        Gets the S3 key prefix information for a specified namespace  # noqa: E501
        """
        pass

    def test_business_object_data_invalidate_unregistered_business_object_data(self):
        """Test case for business_object_data_invalidate_unregistered_business_object_data

        invalidateUnregisteredBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_restore_business_object_data(self):
        """Test case for business_object_data_restore_business_object_data

        restoreBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_retry_storage_policy_transition(self):
        """Test case for business_object_data_retry_storage_policy_transition

        retryStoragePolicyTransition  # noqa: E501
        """
        pass

    def test_business_object_data_search_business_object_data(self):
        """Test case for business_object_data_search_business_object_data

        searchBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes(self):
        """Test case for business_object_data_update_business_object_data_attributes

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes1(self):
        """Test case for business_object_data_update_business_object_data_attributes1

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes2(self):
        """Test case for business_object_data_update_business_object_data_attributes2

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes3(self):
        """Test case for business_object_data_update_business_object_data_attributes3

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes4(self):
        """Test case for business_object_data_update_business_object_data_attributes4

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_legal_hold(self):
        """Test case for business_object_data_update_business_object_data_legal_hold

        updateBusinessObjectDataLegalHold  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_parents(self):
        """Test case for business_object_data_update_business_object_data_parents

        updateBusinessObjectDataParents  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_retention_information(self):
        """Test case for business_object_data_update_business_object_data_retention_information

        updateBusinessObjectDataRetentionInformation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
