# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDefinitionChangeEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'description': 'str',
        'descriptive_business_object_format': 'DescriptiveBusinessObjectFormatUpdateRequest',
        'event_time': 'datetime',
        'user_id': 'str'
    }

    attribute_map = {
        'display_name': 'displayName',
        'description': 'description',
        'descriptive_business_object_format': 'descriptiveBusinessObjectFormat',
        'event_time': 'eventTime',
        'user_id': 'userId'
    }

    def __init__(self, display_name=None, description=None, descriptive_business_object_format=None, event_time=None, user_id=None):  # noqa: E501
        """BusinessObjectDefinitionChangeEvent - a model defined in OpenAPI"""  # noqa: E501

        self._display_name = None
        self._description = None
        self._descriptive_business_object_format = None
        self._event_time = None
        self._user_id = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if description is not None:
            self.description = description
        if descriptive_business_object_format is not None:
            self.descriptive_business_object_format = descriptive_business_object_format
        self.event_time = event_time
        self.user_id = user_id

    @property
    def display_name(self):
        """Gets the display_name of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        Business friendly name  # noqa: E501

        :return: The display_name of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BusinessObjectDefinitionChangeEvent.

        Business friendly name  # noqa: E501

        :param display_name: The display_name of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def description(self):
        """Gets the description of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        Description of the Business Object Definition  # noqa: E501

        :return: The description of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectDefinitionChangeEvent.

        Description of the Business Object Definition  # noqa: E501

        :param description: The description of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def descriptive_business_object_format(self):
        """Gets the descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.  # noqa: E501


        :return: The descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: DescriptiveBusinessObjectFormatUpdateRequest
        """
        return self._descriptive_business_object_format

    @descriptive_business_object_format.setter
    def descriptive_business_object_format(self, descriptive_business_object_format):
        """Sets the descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.


        :param descriptive_business_object_format: The descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: DescriptiveBusinessObjectFormatUpdateRequest
        """

        self._descriptive_business_object_format = descriptive_business_object_format

    @property
    def event_time(self):
        """Gets the event_time of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        The timestamp of when the business object definition update occured  # noqa: E501

        :return: The event_time of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """Sets the event_time of this BusinessObjectDefinitionChangeEvent.

        The timestamp of when the business object definition update occured  # noqa: E501

        :param event_time: The event_time of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: datetime
        """
        if event_time is None:
            raise ValueError("Invalid value for `event_time`, must not be `None`")  # noqa: E501

        self._event_time = event_time

    @property
    def user_id(self):
        """Gets the user_id of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        The User ID of the user who performed business object definition update  # noqa: E501

        :return: The user_id of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BusinessObjectDefinitionChangeEvent.

        The User ID of the user who performed business object definition update  # noqa: E501

        :param user_id: The user_id of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDefinitionChangeEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
