# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class BusinessObjectDefinitionDescriptionSuggestionApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion(self, business_object_definition_description_suggestion_acceptance_request, **kwargs):  # noqa: E501
        """acceptBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Accepts suggested business object definition description suggestion by key and updates the corresponding business object definition description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion(business_object_definition_description_suggestion_acceptance_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest business_object_definition_description_suggestion_acceptance_request: the information needed to accept the business object definition description suggestion. (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_acceptance_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_acceptance_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(self, business_object_definition_description_suggestion_acceptance_request, **kwargs):  # noqa: E501
        """acceptBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Accepts suggested business object definition description suggestion by key and updates the corresponding business object definition description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_acceptance_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest business_object_definition_description_suggestion_acceptance_request: the information needed to accept the business object definition description suggestion. (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_definition_description_suggestion_acceptance_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_definition_description_suggestion_acceptance_request' is set
        if ('business_object_definition_description_suggestion_acceptance_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_acceptance_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_acceptance_request` when calling `business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_acceptance_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_acceptance_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/acceptance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_create_business_object_definition_description_suggestion(self, business_object_definition_description_suggestion_create_request, **kwargs):  # noqa: E501
        """createBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Creates a new business object definition description suggestion.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion(business_object_definition_description_suggestion_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionCreateRequest business_object_definition_description_suggestion_create_request: the information needed to create the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_create_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(self, business_object_definition_description_suggestion_create_request, **kwargs):  # noqa: E501
        """createBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Creates a new business object definition description suggestion.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionCreateRequest business_object_definition_description_suggestion_create_request: the information needed to create the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_definition_description_suggestion_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_create_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_definition_description_suggestion_create_request' is set
        if ('business_object_definition_description_suggestion_create_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_create_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_create_request` when calling `business_object_definition_description_suggestion_create_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_create_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """deleteBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Deletes an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """deleteBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Deletes an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestionByKey  # noqa: E501

        Retrieves an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestionByKey  # noqa: E501

        Retrieves an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestions(self, namespace, business_object_definition_name, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieves a list of business object definition description suggestion keys for all suggestions registered for a specific business object definition. The result list is sorted by userId in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions(namespace, business_object_definition_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :return: BusinessObjectDefinitionDescriptionSuggestionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(namespace, business_object_definition_name, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(namespace, business_object_definition_name, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(self, namespace, business_object_definition_name, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieves a list of business object definition description suggestion keys for all suggestions registered for a specific business object definition. The result list is sorted by userId in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(namespace, business_object_definition_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :return: BusinessObjectDefinitionDescriptionSuggestionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_get_business_object_definition_description_suggestions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestions`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestionKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_search_business_object_definition_description_suggestions(self, business_object_definition_description_suggestion_search_request, **kwargs):  # noqa: E501
        """searchBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieve a list of business object definition description suggestions meeting the search criteria filters and fields request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions(business_object_definition_description_suggestion_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionSearchRequest business_object_definition_description_suggestion_search_request: the search criteria needed to find a list of business object definition description suggestions (required)
        :param str fields: the field options for the business object definition description suggestions search response. The valid field options are: status, descriptionSuggestion, createdByUserId, createdOn
        :return: BusinessObjectDefinitionDescriptionSuggestionSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(business_object_definition_description_suggestion_search_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(business_object_definition_description_suggestion_search_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(self, business_object_definition_description_suggestion_search_request, **kwargs):  # noqa: E501
        """searchBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieve a list of business object definition description suggestions meeting the search criteria filters and fields request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(business_object_definition_description_suggestion_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionSearchRequest business_object_definition_description_suggestion_search_request: the search criteria needed to find a list of business object definition description suggestions (required)
        :param str fields: the field options for the business object definition description suggestions search response. The valid field options are: status, descriptionSuggestion, createdByUserId, createdOn
        :return: BusinessObjectDefinitionDescriptionSuggestionSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_definition_description_suggestion_search_request', 'fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_search_business_object_definition_description_suggestions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_definition_description_suggestion_search_request' is set
        if ('business_object_definition_description_suggestion_search_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_search_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_search_request` when calling `business_object_definition_description_suggestion_search_business_object_definition_description_suggestions`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'fields' in local_var_params:
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_search_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_search_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestionSearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_update_business_object_definition_description_suggestion(self, namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Updates an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :param BusinessObjectDefinitionDescriptionSuggestionUpdateRequest business_object_definition_description_suggestion_update_request: the information needed to update the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(self, namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Updates an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :param BusinessObjectDefinitionDescriptionSuggestionUpdateRequest business_object_definition_description_suggestion_update_request: the information needed to update the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'user_id', 'business_object_definition_description_suggestion_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_update_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'business_object_definition_description_suggestion_update_request' is set
        if ('business_object_definition_description_suggestion_update_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_update_request` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_update_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
