# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_definition_description_suggestion_api import BusinessObjectDefinitionDescriptionSuggestionApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDefinitionDescriptionSuggestionApi(unittest.TestCase):
    """BusinessObjectDefinitionDescriptionSuggestionApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_definition_description_suggestion_api.BusinessObjectDefinitionDescriptionSuggestionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion

        acceptBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_create_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_create_business_object_definition_description_suggestion

        createBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion

        deleteBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key(self):
        """Test case for business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key

        getBusinessObjectDefinitionDescriptionSuggestionByKey  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_get_business_object_definition_description_suggestions(self):
        """Test case for business_object_definition_description_suggestion_get_business_object_definition_description_suggestions

        getBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_search_business_object_definition_description_suggestions(self):
        """Test case for business_object_definition_description_suggestion_search_business_object_definition_description_suggestions

        searchBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_update_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_update_business_object_definition_description_suggestion

        updateBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
