# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_format_to_external_interface_mapping_api import BusinessObjectFormatToExternalInterfaceMappingApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectFormatToExternalInterfaceMappingApi(unittest.TestCase):
    """BusinessObjectFormatToExternalInterfaceMappingApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_format_to_external_interface_mapping_api.BusinessObjectFormatToExternalInterfaceMappingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_formatto_external_interface_mapping_create_business_object_format_external_interface(self):
        """Test case for business_object_formatto_external_interface_mapping_create_business_object_format_external_interface

        createBusinessObjectFormatExternalInterface  # noqa: E501
        """
        pass

    def test_business_object_formatto_external_interface_mapping_delete_business_object_format_external_interface(self):
        """Test case for business_object_formatto_external_interface_mapping_delete_business_object_format_external_interface

        deleteBusinessObjectFormatExternalInterface  # noqa: E501
        """
        pass

    def test_business_object_formatto_external_interface_mapping_get_business_object_format_external_interface(self):
        """Test case for business_object_formatto_external_interface_mapping_get_business_object_format_external_interface

        getBusinessObjectFormatExternalInterface  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
