# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.global_attribute_definition_api import GlobalAttributeDefinitionApi  # noqa: E501
from herdsdk.rest import ApiException


class TestGlobalAttributeDefinitionApi(unittest.TestCase):
    """GlobalAttributeDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.global_attribute_definition_api.GlobalAttributeDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_global_attribute_definition_create_global_attribute_definition(self):
        """Test case for global_attribute_definition_create_global_attribute_definition

        createGlobalAttributeDefinition  # noqa: E501
        """
        pass

    def test_global_attribute_definition_delete_global_attribute_definition(self):
        """Test case for global_attribute_definition_delete_global_attribute_definition

        deleteGlobalAttributeDefinition  # noqa: E501
        """
        pass

    def test_global_attribute_definition_get_global_attribute_definition(self):
        """Test case for global_attribute_definition_get_global_attribute_definition

        getGlobalAttributeDefinition  # noqa: E501
        """
        pass

    def test_global_attribute_definition_get_global_attribute_definitions(self):
        """Test case for global_attribute_definition_get_global_attribute_definitions

        getGlobalAttributeDefinitions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
