# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class JobDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'namespace': 'str',
        'job_name': 'str',
        'description': 'str',
        'activiti_job_xml': 'str',
        'parameters': 'list[Parameter]',
        's3_properties_location': 'S3PropertiesLocation',
        'last_updated_by_user_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'namespace': 'namespace',
        'job_name': 'jobName',
        'description': 'description',
        'activiti_job_xml': 'activitiJobXml',
        'parameters': 'parameters',
        's3_properties_location': 's3PropertiesLocation',
        'last_updated_by_user_id': 'lastUpdatedByUserId'
    }

    def __init__(self, id=None, namespace=None, job_name=None, description=None, activiti_job_xml=None, parameters=None, s3_properties_location=None, last_updated_by_user_id=None):  # noqa: E501
        """JobDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._namespace = None
        self._job_name = None
        self._description = None
        self._activiti_job_xml = None
        self._parameters = None
        self._s3_properties_location = None
        self._last_updated_by_user_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.namespace = namespace
        self.job_name = job_name
        if description is not None:
            self.description = description
        self.activiti_job_xml = activiti_job_xml
        if parameters is not None:
            self.parameters = parameters
        if s3_properties_location is not None:
            self.s3_properties_location = s3_properties_location
        if last_updated_by_user_id is not None:
            self.last_updated_by_user_id = last_updated_by_user_id

    @property
    def id(self):
        """Gets the id of this JobDefinition.  # noqa: E501

        The internal identifier that uniquely references a job definition  # noqa: E501

        :return: The id of this JobDefinition.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobDefinition.

        The internal identifier that uniquely references a job definition  # noqa: E501

        :param id: The id of this JobDefinition.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def namespace(self):
        """Gets the namespace of this JobDefinition.  # noqa: E501

        The namespace of the job definition  # noqa: E501

        :return: The namespace of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this JobDefinition.

        The namespace of the job definition  # noqa: E501

        :param namespace: The namespace of this JobDefinition.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def job_name(self):
        """Gets the job_name of this JobDefinition.  # noqa: E501

        The name of the job definition  # noqa: E501

        :return: The job_name of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this JobDefinition.

        The name of the job definition  # noqa: E501

        :param job_name: The job_name of this JobDefinition.  # noqa: E501
        :type: str
        """
        if job_name is None:
            raise ValueError("Invalid value for `job_name`, must not be `None`")  # noqa: E501

        self._job_name = job_name

    @property
    def description(self):
        """Gets the description of this JobDefinition.  # noqa: E501

        Description of the job definition  # noqa: E501

        :return: The description of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this JobDefinition.

        Description of the job definition  # noqa: E501

        :param description: The description of this JobDefinition.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def activiti_job_xml(self):
        """Gets the activiti_job_xml of this JobDefinition.  # noqa: E501

        Activiti workflow XML related to the job  # noqa: E501

        :return: The activiti_job_xml of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._activiti_job_xml

    @activiti_job_xml.setter
    def activiti_job_xml(self, activiti_job_xml):
        """Sets the activiti_job_xml of this JobDefinition.

        Activiti workflow XML related to the job  # noqa: E501

        :param activiti_job_xml: The activiti_job_xml of this JobDefinition.  # noqa: E501
        :type: str
        """
        if activiti_job_xml is None:
            raise ValueError("Invalid value for `activiti_job_xml`, must not be `None`")  # noqa: E501

        self._activiti_job_xml = activiti_job_xml

    @property
    def parameters(self):
        """Gets the parameters of this JobDefinition.  # noqa: E501

        Default list of key/value pairs that will be made available to the job when it is executed. These values can be overridden by                   parameters                   specified during the job execution                  # noqa: E501

        :return: The parameters of this JobDefinition.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this JobDefinition.

        Default list of key/value pairs that will be made available to the job when it is executed. These values can be overridden by                   parameters                   specified during the job execution                  # noqa: E501

        :param parameters: The parameters of this JobDefinition.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def s3_properties_location(self):
        """Gets the s3_properties_location of this JobDefinition.  # noqa: E501


        :return: The s3_properties_location of this JobDefinition.  # noqa: E501
        :rtype: S3PropertiesLocation
        """
        return self._s3_properties_location

    @s3_properties_location.setter
    def s3_properties_location(self, s3_properties_location):
        """Sets the s3_properties_location of this JobDefinition.


        :param s3_properties_location: The s3_properties_location of this JobDefinition.  # noqa: E501
        :type: S3PropertiesLocation
        """

        self._s3_properties_location = s3_properties_location

    @property
    def last_updated_by_user_id(self):
        """Gets the last_updated_by_user_id of this JobDefinition.  # noqa: E501

        The user ID under whose authorization context the workflow runs  # noqa: E501

        :return: The last_updated_by_user_id of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._last_updated_by_user_id

    @last_updated_by_user_id.setter
    def last_updated_by_user_id(self, last_updated_by_user_id):
        """Sets the last_updated_by_user_id of this JobDefinition.

        The user ID under whose authorization context the workflow runs  # noqa: E501

        :param last_updated_by_user_id: The last_updated_by_user_id of this JobDefinition.  # noqa: E501
        :type: str
        """

        self._last_updated_by_user_id = last_updated_by_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
