# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.user_namespace_authorization_api import UserNamespaceAuthorizationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestUserNamespaceAuthorizationApi(unittest.TestCase):
    """UserNamespaceAuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.user_namespace_authorization_api.UserNamespaceAuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_namespace_authorization_create_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_create_user_namespace_authorization

        createUserNamespaceAuthorization  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_delete_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_delete_user_namespace_authorization

        deleteUserNamespaceAuthorization  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_delete_user_namespace_authorizations_by_user_id(self):
        """Test case for user_namespace_authorization_delete_user_namespace_authorizations_by_user_id

        deleteUserNamespaceAuthorizationsByUserId  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_get_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_get_user_namespace_authorization

        getUserNamespaceAuthorization  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_get_user_namespace_authorizations_by_namespace(self):
        """Test case for user_namespace_authorization_get_user_namespace_authorizations_by_namespace

        getUserNamespaceAuthorizationsByNamespace  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_get_user_namespace_authorizations_by_user_id(self):
        """Test case for user_namespace_authorization_get_user_namespace_authorizations_by_user_id

        getUserNamespaceAuthorizationsByUserId  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_update_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_update_user_namespace_authorization

        updateUserNamespaceAuthorization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
