# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_definition_column_api import BusinessObjectDefinitionColumnApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDefinitionColumnApi(unittest.TestCase):
    """BusinessObjectDefinitionColumnApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_definition_column_api.BusinessObjectDefinitionColumnApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_definition_column_create_business_object_definition_column(self):
        """Test case for business_object_definition_column_create_business_object_definition_column

        createBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass

    def test_business_object_definition_column_delete_business_object_definition_column(self):
        """Test case for business_object_definition_column_delete_business_object_definition_column

        deleteBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass

    def test_business_object_definition_column_get_business_object_definition_column(self):
        """Test case for business_object_definition_column_get_business_object_definition_column

        getBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass

    def test_business_object_definition_column_get_business_object_definition_columns(self):
        """Test case for business_object_definition_column_get_business_object_definition_columns

        getBusinessObjectDefinitionColumns  # noqa: E501
        """
        pass

    def test_business_object_definition_column_search_business_object_definition_columns(self):
        """Test case for business_object_definition_column_search_business_object_definition_columns

        searchBusinessObjectDefinitionColumns  # noqa: E501
        """
        pass

    def test_business_object_definition_column_update_business_object_definition_column(self):
        """Test case for business_object_definition_column_update_business_object_definition_column

        updateBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
