# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.security_role_api import SecurityRoleApi  # noqa: E501
from herdsdk.rest import ApiException


class TestSecurityRoleApi(unittest.TestCase):
    """SecurityRoleApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.security_role_api.SecurityRoleApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_security_role_create_security_role(self):
        """Test case for security_role_create_security_role

        createSecurityRole  # noqa: E501
        """
        pass

    def test_security_role_delete_security_role(self):
        """Test case for security_role_delete_security_role

        deleteSecurityRole  # noqa: E501
        """
        pass

    def test_security_role_get_security_role(self):
        """Test case for security_role_get_security_role

        getSecurityRole  # noqa: E501
        """
        pass

    def test_security_role_get_security_roles(self):
        """Test case for security_role_get_security_roles

        getSecurityRoles  # noqa: E501
        """
        pass

    def test_security_role_update_security_role(self):
        """Test case for security_role_update_security_role

        updateSecurityRole  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
