# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.storage_api import StorageApi  # noqa: E501
from herdsdk.rest import ApiException


class TestStorageApi(unittest.TestCase):
    """StorageApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.storage_api.StorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_storage_create_storage(self):
        """Test case for storage_create_storage

        createStorage  # noqa: E501
        """
        pass

    def test_storage_delete_storage(self):
        """Test case for storage_delete_storage

        deleteStorage  # noqa: E501
        """
        pass

    def test_storage_get_storage(self):
        """Test case for storage_get_storage

        getStorage  # noqa: E501
        """
        pass

    def test_storage_get_storages(self):
        """Test case for storage_get_storages

        getStorages  # noqa: E501
        """
        pass

    def test_storage_update_storage(self):
        """Test case for storage_update_storage

        updateStorage  # noqa: E501
        """
        pass

    def test_storage_update_storage_attributes(self):
        """Test case for storage_update_storage_attributes

        updateStorageAttributes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
