# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.namespace_api import NamespaceApi  # noqa: E501
from herdsdk.rest import ApiException


class TestNamespaceApi(unittest.TestCase):
    """NamespaceApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.namespace_api.NamespaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_namespace_create_namespace(self):
        """Test case for namespace_create_namespace

        createNamespace  # noqa: E501
        """
        pass

    def test_namespace_delete_namespace(self):
        """Test case for namespace_delete_namespace

        deleteNamespace  # noqa: E501
        """
        pass

    def test_namespace_get_namespace(self):
        """Test case for namespace_get_namespace

        getNamespace  # noqa: E501
        """
        pass

    def test_namespace_get_namespaces(self):
        """Test case for namespace_get_namespaces

        getNamespaces  # noqa: E501
        """
        pass

    def test_namespace_search_namespaces(self):
        """Test case for namespace_search_namespaces

        searchNamespaces  # noqa: E501
        """
        pass

    def test_namespace_update_namespaces(self):
        """Test case for namespace_update_namespaces

        updateNamespaces  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
