# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.namespace_iam_role_authorization_api import NamespaceIAMRoleAuthorizationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestNamespaceIAMRoleAuthorizationApi(unittest.TestCase):
    """NamespaceIAMRoleAuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.namespace_iam_role_authorization_api.NamespaceIAMRoleAuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_namespace_iam_role_authorization_create_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_create_namespace_iam_role_authorization

        createNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_delete_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_delete_namespace_iam_role_authorization

        deleteNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorization

        getNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorizations(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorizations

        getNamespaceIamRoleAuthorizations  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_iam_role_name(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_iam_role_name

        getNamespaceIamRoleAuthorizationsByIamRoleName  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_namespace(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_namespace

        getNamespaceIamRoleAuthorizationsByNamespace  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_update_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_update_namespace_iam_role_authorization

        updateNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
