# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.storage_unit_notification_registration_api import StorageUnitNotificationRegistrationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestStorageUnitNotificationRegistrationApi(unittest.TestCase):
    """StorageUnitNotificationRegistrationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.storage_unit_notification_registration_api.StorageUnitNotificationRegistrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_storage_unit_notification_registration_create_storage_unit_notification_registration(self):
        """Test case for storage_unit_notification_registration_create_storage_unit_notification_registration

        createStorageUnitNotificationRegistration  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_delete_storage_unit_notification(self):
        """Test case for storage_unit_notification_registration_delete_storage_unit_notification

        deleteStorageUnitNotification  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_get_storage_unit_notification_registration(self):
        """Test case for storage_unit_notification_registration_get_storage_unit_notification_registration

        getStorageUnitNotificationRegistration  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_get_storage_unit_notification_registrations_by_namespace(self):
        """Test case for storage_unit_notification_registration_get_storage_unit_notification_registrations_by_namespace

        getStorageUnitNotificationRegistrationsByNamespace  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_get_storage_unit_notification_registrations_by_notification_filter(self):
        """Test case for storage_unit_notification_registration_get_storage_unit_notification_registrations_by_notification_filter

        getStorageUnitNotificationRegistrationsByNotificationFilter  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_update_storage_unit_notification_registration(self):
        """Test case for storage_unit_notification_registration_update_storage_unit_notification_registration

        updateStorageUnitNotificationRegistration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
