# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.job_api import JobApi  # noqa: E501
from herdsdk.rest import ApiException


class TestJobApi(unittest.TestCase):
    """JobApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.job_api.JobApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_create_job(self):
        """Test case for job_create_job

        createJob  # noqa: E501
        """
        pass

    def test_job_delete_job(self):
        """Test case for job_delete_job

        deleteJob  # noqa: E501
        """
        pass

    def test_job_get_job(self):
        """Test case for job_get_job

        getJob  # noqa: E501
        """
        pass

    def test_job_get_jobs(self):
        """Test case for job_get_jobs

        getJobs  # noqa: E501
        """
        pass

    def test_job_signal_job(self):
        """Test case for job_signal_job

        signalJob  # noqa: E501
        """
        pass

    def test_job_update_job(self):
        """Test case for job_update_job

        updateJob  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
