# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.emr_api import EMRApi  # noqa: E501
from herdsdk.rest import ApiException


class TestEMRApi(unittest.TestCase):
    """EMRApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.emr_api.EMRApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_e_mr_add_hadoop_jar_step_to_emr_cluster(self):
        """Test case for e_mr_add_hadoop_jar_step_to_emr_cluster

        addHadoopJarStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_add_hive_step_to_emr_cluster(self):
        """Test case for e_mr_add_hive_step_to_emr_cluster

        addHiveStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_add_pig_step_to_emr_cluster(self):
        """Test case for e_mr_add_pig_step_to_emr_cluster

        addPigStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_add_shell_step_to_emr_cluster(self):
        """Test case for e_mr_add_shell_step_to_emr_cluster

        addShellStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_create_emr_cluster(self):
        """Test case for e_mr_create_emr_cluster

        createEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_get_emr_cluster(self):
        """Test case for e_mr_get_emr_cluster

        getEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_terminate_emr_cluster(self):
        """Test case for e_mr_terminate_emr_cluster

        terminateEmrCluster  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
