# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.emr_cluster_definition_api import EMRClusterDefinitionApi  # noqa: E501
from herdsdk.rest import ApiException


class TestEMRClusterDefinitionApi(unittest.TestCase):
    """EMRClusterDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.emr_cluster_definition_api.EMRClusterDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_e_mr_cluster_definition_create_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_create_emr_cluster_definition

        createEmrClusterDefinition  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_delete_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_delete_emr_cluster_definition

        deleteEmrClusterDefinition  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_get_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_get_emr_cluster_definition

        getEmrClusterDefinition  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_get_emr_cluster_definitions(self):
        """Test case for e_mr_cluster_definition_get_emr_cluster_definitions

        getEmrClusterDefinitions  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_update_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_update_emr_cluster_definition

        updateEmrClusterDefinition  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
